const CACHE_NAME = 'five-league-cache-v1';

// キャッシュするリソースを定義
const urlsToCache = [
    '/tools/5league/',
    '/tools/5league/css/styles.css',
    '/tools/5league/js/main.js',
    '/tools/5league/js/admin.js'
];

// インストール時の処理
self.addEventListener('install', (event) => {
    event.waitUntil(
        caches.open(CACHE_NAME)
            .then(cache => {
                return cache.addAll(urlsToCache);
            })
    );
});

// フェッチ時の処理
self.addEventListener('fetch', (event) => {
    // CDNリソースは直接フェッチする
    if (event.request.url.startsWith('https://cdnjs.cloudflare.com')) {
        event.respondWith(fetch(event.request));
        return;
    }

    event.respondWith(
        caches.match(event.request)
            .then(response => {
                if (response) {
                    return response;
                }
                return fetch(event.request);
            })
    );
});

// アクティベート時の処理
self.addEventListener('activate', (event) => {
    event.waitUntil(
        caches.keys().then(cacheNames => {
            return Promise.all(
                cacheNames.map(cacheName => {
                    if (cacheName !== CACHE_NAME) {
                        return caches.delete(cacheName);
                    }
                })
            );
        })
    );
});